@@ -19,11 +19,14 @@
 #include <QDir>
 #include <QStringList>
 #include <QtGlobal>
+#include <QTextCodec>
 #include <qmetaobject.h>
 
 #include <iostream>
 
+#ifdef ZLIB_FOUND
 #include <zlib.h>
+#endif
 
 #ifdef Q_OS_WIN
 #include <io.h> // for stdout
@@ -119,7 +122,7 @@ void Logger::log(Log log)
 bool Logger::isNoop() const
 {
     QMutexLocker lock(&_mutex);
-    return !_logstream && !_logWindowActivated;
+    return !_logstream;
 }
 
 bool Logger::isLoggingToFile() const
@@ -161,12 +164,6 @@ void Logger::mirallLog(const QString &message)
     Logger::instance()->log(log_);
 }
 
-void Logger::setLogWindowActivated(bool activated)
-{
-    QMutexLocker locker(&_mutex);
-    _logWindowActivated = activated;
-}
-
 QString Logger::logFile() const
 {
     return _logFile.fileName();
@@ -202,6 +199,7 @@ void Logger::setLogFile(const QString &name)
     }
 
     _logstream.reset(new QTextStream(&_logFile));
+    _logstream->setCodec(QTextCodec::codecForName("UTF-8"));
 }
 
 void Logger::setLogExpire(int expire)
@@ -261,6 +259,7 @@ void Logger::disableTemporaryFolderLogDir()
 
 static bool compressLog(const QString &originalName, const QString &targetName)
 {
+#ifdef ZLIB_FOUND
     QFile original(originalName);
     if (!original.open(QIODevice::ReadOnly))
         return false;
@@ -279,6 +278,9 @@ static bool compressLog(const QString &originalName, const QString &targetName)
     }
     gzclose(compressed);
     return true;
+#else
+    return false;
+#endif
 }
 
 void Logger::enterNextLogFile()
